==> login_firebase-0.0.2.tar.gz: lib/presentation/widgets/single/AppleSigninWidget.dart <==
import 'package:flutter/material.dart';
import 'package:login_firebase/business/dto/ModSessionDTO.dart';
import 'package:login_firebase/common/ModErrorCodes.dart';
import 'package:login_firebase/common/ModLogger.dart';
import 'package:login_firebase/models/ModResourceResult.dart';
import 'package:login_firebase/models/ThirdPartyErrorModel.dart';
import 'package:login_firebase/models/ThirdPartySessionModel.dart';
import 'package:login_firebase/presentation/factories/LoginIconButtonFactory.dart';
import 'package:login_firebase/presentation/factories/LoginWidgetFactory.dart';
import 'package:login_firebase/presentation/widgets/convenient/ModLoadingWidget.dart';

import '../../../business/bloc/AppleSigninBloc.dart';
import '../base/ModBaseStatelessWidgetWithBloc.dart';


const String TAG = "AppleSigninWidget";


/**
 * Widget that performs Apple sign-in
 */
//ignore: must_be_immutable
class AppleSigninWidget extends ModBaseStatelessWidgetWithBloc<AppleSigninBloc, ThirdPartySessionModel> {
  final Function(ThirdPartySessionModel?) onSessionSuccess;
  final Function(int) onSessionError;
  final Function() onReset;
  final Function(String)? onDisplay;
  final bool available;
  final String btnText;
  final Color? loadingColor;

  AppleSigninWidget({
    required this.onSessionSuccess,
    required this.onSessionError,
    required this.onReset,
    this.onDisplay,
    this.available = false,
    required this.btnText,
    this.loadingColor,
    Key? key})
      : super(key: key);

  @override
  void initBloc(BuildContext context) {
    this.bloc = AppleSigninBloc();
  }

  void _call() {
    this.bloc!.processData(ModResourceResult(state: ResourceState.LOADING, data: null, error: null));
    this.bloc!.performOperation(ModSessionDTO(mail: "", pass: ""));
  }

  @override
  Widget buildInitialState(BuildContext context) {
    return this._wrap(this._buildButton(context));
  }

  @override
  Widget buildLoadingState(BuildContext context) {
    final btn = this._buildButton(context);

    return this._wrap(Stack(children: <Widget>[
      btn,
      ModLoadingWidget(color: this.loadingColor,)
    ],));
  }

  @override
  Widget buildSuccessState(BuildContext context, ThirdPartySessionModel? data) {
    final btn = this._buildButton(context);
    if (data!.validate()) {
      this.onSessionSuccess.call(data);
    } else {
      ModLogger.i(tag: TAG, msg: "cancelled by user");

      //TODO: check if call needed
      this.onSessionError.call(ModErrorCodes.INVALID_SESSION);
    }
    return this._wrap(btn);
  }

  @override
  Widget buildErrorState(BuildContext context, ThirdPartyErrorModel? error) {
    final btn = this._buildButton(context);
    this.onSessionError.call(error!.code);
    return this._wrap(btn);
  }

  Widget _wrap(Widget child) => Container(
      margin: EdgeInsets.symmetric(horizontal: 8.0),
      padding: EdgeInsets.all(4.0),
      child: Center(child: child)
  );

  Widget _buildButton(BuildContext context) =>
      LangAppleSignInButton(
        btnText: this.btnText,
        style: LangButtonStyle.black,
        cornerRadius: 50.0,
        type: LangButtonType.continueButton,
        onPressed: this.available ?
          // AVAIL
          ()  {
            this.onReset.call();

            this._call();
          }
          :
          // NOT AVAIL
          () {
              this.onSessionError(ModErrorCodes.SIGNIN_NOT_AVAILABLE);
          },
      );
}


/// A type for the authorization button.
enum LangButtonType { defaultButton, continueButton, signIn }


/// A style for the authorization button.
enum LangButtonStyle { black, whiteOutline, white }


/**
 * Helper class
 */
class LangAppleSignInButton extends StatefulWidget {

  final String btnText;

  /// The callback that is called when the button is tapped or otherwise activated.
  ///
  /// If this is set to null, the button will be disabled.
  final VoidCallback onPressed;

  /// A type for the authorization button.
  final LangButtonType type;

  /// A style for the authorization button.
  final LangButtonStyle style;

  /// A custom corner radius to be used by this button.
  final double cornerRadius;

  const LangAppleSignInButton({
    required this.btnText,
    required this.onPressed,
    this.type = LangButtonType.defaultButton,
    this.style = LangButtonStyle.black,
    this.cornerRadius = 6,
  });

  @override
  State<StatefulWidget> createState() => _LangAppleSignInButtonState();
}

/**
 * Companion state for helper class
 */
class _LangAppleSignInButtonState extends State<LangAppleSignInButton> {

  @override
  Widget build(BuildContext context) {
    final bgColor =
    widget.style == LangButtonStyle.black ? Colors.black : Colors.white;
    final textColor =
    widget.style == LangButtonStyle.black ? Colors.white : Colors.black;
    final borderColor =
    widget.style == LangButtonStyle.white ? Colors.white : Colors.black;

    return LoginWidgetFactory.buildSigninBtn(
        context: context,
        containerColor: bgColor,
        borderColor: borderColor,
        icon: LoginIconButtonFactory.getAppleIcon(height: 25.0, width: 25.0),
        text: this.widget.btnText,
        textColor: textColor,
        onClick: this.widget.onPressed
    );
  }
}

==> login_firebase-0.0.4.tar.gz: lib/presentation/widgets/single/AppleSigninWidget.dart <==
import 'package:flutter/material.dart';
import 'package:login_firebase/business/dto/ModSessionDTO.dart';
import 'package:login_firebase/common/ModErrorCodes.dart';
import 'package:login_firebase/common/ModLogger.dart';
import 'package:login_firebase/models/ModResourceResult.dart';
import 'package:login_firebase/models/ThirdPartyErrorModel.dart';
import 'package:login_firebase/models/ThirdPartySessionModel.dart';
import 'package:login_firebase/presentation/factories/LoginIconButtonFactory.dart';
import 'package:login_firebase/presentation/factories/LoginWidgetFactory.dart';
import 'package:login_firebase/presentation/widgets/convenient/ModLoadingWidget.dart';

import '../../../business/bloc/AppleSigninBloc.dart';
import '../base/ModBaseStatelessWidgetWithBloc.dart';


const String TAG = "AppleSigninWidget";


//ignore: must_be_immutable
class AppleSigninWidget extends ModBaseStatelessWidgetWithBloc<AppleSigninBloc, ThirdPartySessionModel> {
  final Function(ThirdPartySessionModel?) onSessionSuccess;
  final Function(int) onSessionError;
  final Function() onReset;
  final Function(String)? onDisplay;
  final bool available;
  final String btnText;
  final Color? loadingColor;

  AppleSigninWidget({
    required this.onSessionSuccess,
    required this.onSessionError,
    required this.onReset,
    this.onDisplay,
    this.available = false,
    required this.btnText,
    this.loadingColor,
    super.key});

  @override
  void initBloc(BuildContext context) {
    bloc = AppleSigninBloc();
  }

  void _call() {
    bloc!.processData(ModResourceResult(state: ResourceState.LOADING, data: null, error: null));
    bloc!.performOperation(const ModSessionDTO(mail: "", pass: ""));
  }

  @override
  Widget buildInitialState(BuildContext context) {
    return _wrap(_buildButton(context));
  }

  @override
  Widget buildLoadingState(BuildContext context) {
    final btn = _buildButton(context);

    return _wrap(Stack(children: <Widget>[
      btn,
      ModLoadingWidget(color: loadingColor,)
    ],));
  }

  @override
  Widget buildSuccessState(BuildContext context, ThirdPartySessionModel? data) {
    final btn = _buildButton(context);
    if (data!.validate()) {
      onSessionSuccess.call(data);
    } else {
      ModLogger.i(tag: TAG, msg: "cancelled by user");

      onSessionError.call(ModErrorCodes.INVALID_SESSION);
    }
    return _wrap(btn);
  }

  @override
  Widget buildErrorState(BuildContext context, ThirdPartyErrorModel? error) {
    final btn = _buildButton(context);
    onSessionError.call(error!.code);
    return _wrap(btn);
  }

  Widget _wrap(Widget child) => Container(
      margin: const EdgeInsets.symmetric(horizontal: 8.0),
      padding: const EdgeInsets.all(4.0),
      child: Center(child: child)
  );

  Widget _buildButton(BuildContext context) =>
      LangAppleSignInButton(
        btnText: btnText,
        style: LangButtonStyle.black,
        cornerRadius: 50.0,
        type: LangButtonType.continueButton,
        onPressed: available ?
          // AVAIL
          ()  {
            onReset.call();

            _call();
          }
          :
          // NOT AVAIL
          () {
              onSessionError(ModErrorCodes.SIGNIN_NOT_AVAILABLE);
          },
      );
}


/// A type for the authorization button.
enum LangButtonType { defaultButton, continueButton, signIn }


/// A style for the authorization button.
enum LangButtonStyle { black, whiteOutline, white }



class LangAppleSignInButton extends StatefulWidget {

  final String btnText;

  /// The callback that is called when the button is tapped or otherwise activated.
  ///
  /// If this is set to null, the button will be disabled.
  final VoidCallback onPressed;

  /// A type for the authorization button.
  final LangButtonType type;

  /// A style for the authorization button.
  final LangButtonStyle style;

  /// A custom corner radius to be used by this button.
  final double cornerRadius;

  const LangAppleSignInButton({super.key,
    required this.btnText,
    required this.onPressed,
    this.type = LangButtonType.defaultButton,
    this.style = LangButtonStyle.black,
    this.cornerRadius = 6,
  });

  @override
  State<StatefulWidget> createState() => _LangAppleSignInButtonState();
}


class _LangAppleSignInButtonState extends State<LangAppleSignInButton> {

  @override
  Widget build(BuildContext context) {
    final bgColor =
    widget.style == LangButtonStyle.black ? Colors.black : Colors.white;
    final textColor =
    widget.style == LangButtonStyle.black ? Colors.white : Colors.black;
    final borderColor =
    widget.style == LangButtonStyle.white ? Colors.white : Colors.black;

    return LoginWidgetFactory.buildSigninBtn(
        context: context,
        containerColor: bgColor,
        borderColor: borderColor,
        icon: LoginIconButtonFactory.getAppleIcon(height: 25.0, width: 25.0),
        text: widget.btnText,
        textColor: textColor,
        onClick: widget.onPressed
    );
  }
}
